@@ -54,9 +54,9 @@ class Map(LeafletMap):
         self.add(self.railwaymap)
         self.railwaymap.opacity = 0.4
         # noinspection PyUnresolvedReferences
-        # positron = basemap_to_tiles(basemaps.CartoDB.Positron)
-        # positron.base = True
-        # self.add(positron)
+        positron = basemap_to_tiles(basemaps.CartoDB.Positron)
+        positron.base = True
+        self.add(positron)
 
     def add_measurements(self, campaign: 'Campaign') -> Union[None, List[LayerGroup]]:
         """ Add all GPS tracks from the campaign files to a Map
@@ -221,8 +221,6 @@ def create_marker(pos: Tuple[float, float], popup: Union[str, HTML] = None, colo
 
 
 def create_measurement_layer(file: RDYFile):
-    measurement_layer = LayerGroup()
-    measurement_layer.name = file.filename
 
     gps_series = file.measurements[GPSSeries]
     coords = gps_series.to_ipyleaflef()
@@ -231,6 +229,9 @@ def create_measurement_layer(file: RDYFile):
         logger.warning(f"Coordinates are empty in file: {file.filename}")
         return
 
+    measurement_layer = LayerGroup()
+    measurement_layer.name = file.filename
+
     file_polyline = Polyline(locations=coords, color=file.color, fill=False, weight=4,
                              dash_array='10, 10')
     file_message = HTML()
